/** \file
 * This header defines the types used in ATL.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Cong Loc Kieu, Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef AtlTypes_h
#define AtlTypes_h


#if !defined(AVATL_MAC) && !defined(AVATL_WIN) && !defined(AVATL_UNIX)
	#if defined(__GNUC__)
		#if defined(__APPLE_CPP__) || defined(__APPLE_CC__)
			#define	AVATL_MAC		1
			#define	AVATL_MACHO		1
		#elif defined(__MACOS_CLASSIC__)
			#define	AVATL_MAC		1
			#define	AVATL_CFM		1
		#else
			#define	AVATL_UNIX		1
		#endif
	#elif defined(__MWERKS__)
		#if defined(__MACH__)
			#define	AVATL_MAC		1
			#define	AVATL_MACHO		1
		#elif defined(macintosh) && macintosh
			#define	AVATL_MAC		1
			#define	AVATL_CFM		1
		#elif defined(__INTEL__)
			#define	AVATL_WIN		1
                #else
                    #error Please specify platform
		#endif
	#elif defined(WIN32) || defined(_WIN32)
		#define	AVATL_WIN			1
		#pragma warning(disable: 4786) // Eliminate VC6 warnings about STL & Debug 255 char limits
	#else
		#error Please specify platform
	#endif
#endif


/// If we are building the dynamic library, we have to export some functions.
#ifdef BUILD_ATL
	#ifdef __MWERKS__
 	   #define AVATL_EXP	__declspec(export)
	#else
 	   #define AVATL_EXP	__declspec(dllexport)
	#endif
#else
   #define AVATL_EXP
#endif


/// Specify the calling convention for ATL functions
#if defined(AVATL_WIN)
   #define AVATL_CALL_CONVENTION __cdecl
#else
   #define AVATL_CALL_CONVENTION
#endif


/// Inform that nthis version of ATL have standard XYZ convention
#define AVATL_STD_XYZ	1


#include <string>


/// Forward declaration for class AbventXML::XIXMLElement
namespace AbventXML
{
	class XIXMLElement;
	class XCXMLTree;
}

/// namespace and typedef for the Abvent ATL library
/** \namespace AvAtl
 * We use this namespace for all members of the ATL library.
 * \author Abvent R&D Copyright (c) 2002-2003
 */
namespace  AvAtl {

// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif

/// Name to specify a big size float type (Currently it is always 64 Bits)
typedef double	ATLDouble;

/// Name to specify a standard size float type (Currently it is always 32 Bits)
typedef float	ATLFloat;

#if defined(_64) || defined(__LP64__)

/// Name to specify a efficient float type (64 Bits in 64 Bits model)
typedef double	ATLReal;

#else

/// Name to specify a efficient float type (32 Bits in 32 Bits model)
typedef float	ATLReal;

#endif

/// Name to specify a precise float type
typedef ATLDouble	ATLRealPrecise;


/// Name for 8 bits integer
typedef char				ATLSInt8;

/// Name for 8 bits unsigned integer
typedef unsigned char		ATLUInt8;

/// Name for 16 bits integer
typedef short				ATLSInt16;

/// Name for 16 bits unsigned integer
typedef unsigned short		ATLUInt16;

/// Name for 32 bits integer
typedef int					ATLSInt32;

/// Name for 32 bits unsigned integer
typedef unsigned int		ATLUInt32;

#if defined(__LP64__)

/// Name for 64 bits integer
typedef long				ATLSInt64;

/// Name for 64 bits unsigned integer
typedef unsigned long		ATLUInt64;

/// Name for indexor
typedef ATLUInt64			ATLIndex;

#else

#ifdef LL__int64 // VC6 64 bit interger

/// Name for 64 bits integer
typedef __int64				ATLSInt64;

/// Name for 64 bits unsigned integer
typedef unsigned __int64	ATLUInt64;

#else

/// Name for 64 bits integer
typedef long long			ATLSInt64;

/// Name for 64 bits unsigned integer
typedef unsigned long long	ATLUInt64;

#endif

/// Name for indexor
typedef ATLUInt32			ATLIndex;

#endif


/// Name to specify a unicode character.
/** ATL uses unicode characters (utf8) for all texts. */
typedef char				tUtf8Char;
/// Name to specify a unicode string (as array of chars).
typedef const tUtf8Char*	tUtf8;
/// Name to specify a unicode string (as std::string)
typedef std::string			tUtf8String;

/// Name to specify system encoding (for use with  CAtlUtf8Transcoder.h)
#if defined(AVATL_MAC)
#if __LP64__
	typedef unsigned int	tOSCode;			// TextEncodingBase on Macintosh
#else
	typedef unsigned long	tOSCode;			// TextEncodingBase on Macintosh
#endif
#else
	typedef unsigned int	tOSCode;			// Code page on windows
#endif

/// Name to specify a URL character
/** ATL uses URLs for all references to documents. */
typedef char				tURLChar;
/// Name to specify a URL string (as array of chars).
typedef const tURLChar*		tURL;
/// Name to specify a URL string (as std::string)
typedef std::string			tURLString;

/// Name to specify a Universal Unique IDentifier
typedef const class CAtlUUID&	tUUID;

/// Forward declaration for localizable string
class IAtlString;

/// Name for XMLElementNode pointer.
/** Usage of this type is exclusive to Abvent. */
typedef AbventXML::XIXMLElement*			XMLNodeRef;

/// Name for pointer to const XMLElementNode.
/** Usage of this type is exclusive to Abvent. */
typedef const AbventXML::XIXMLElement*		ConstXMLNodeRef;

/// Name for XCXMLTree pointer.
/** Usage of this type is exclusive to Abvent. */
typedef AbventXML::XCXMLTree*				XMLTreeRef;

/// Version of ATL header used for compilation.
/** This value is automatically passed as needed. */
enum EVersionATL			{ kATL_Version = 44 };



/// Enumeration of readability of for a file.
typedef enum
{
	kFileUnknown,		/// The format of the file isn't recognized.
	kFileOlder,			/// The format of the file is older than current. Cannot be reopen by the application which has created it.
	kFileOlderButSafe,	/// The format of the file is older than current. But it can be reopen by the application which has created it.
	kFileCurrent,		/// The format of the file is current.
	kFileNewerSafe,		/// The format of the file is nerwer than current but must be readeable without lost ???
	kFileNewer,			/// The format of the file is newer, readeable with some data lost.
	kFileTooNew,		/// The format of the file is too new (cannot be read)

	kExportedFile		/// This file has been exported from an another application.
} eReadability;


/// Version of extended ATL header used for compilation.
/** For Abvent usage only.
 * This value is automatically passed as needed. */
enum EExtendedVersionATL	{ kATLEx_Version = 9 };


#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif

} // namespace  AvAtl

#endif
