/*!
	\file	IAtlAnimatedElement.h
	\date	04 08 05
	\author	Abvent R&D copyright (c) 2005
	\author	Guillaume Boulet-Gercourt
	Header for the IAtlAnimatedElement interface.
*/
#ifndef		IAtlAnimatedElement_h
# define	IAtlAnimatedElement_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef IAtlInterpolatedValue_h
	#include "IAtlInterpolatedValue.h"
#endif

namespace	AvAtl {

/// List of animated elements.
typedef TAtlObjectMgr<class IAtlAnimatedElement>		AtlAnimatedElementsMgr;

/*!
	\interface	IAtlAnimatedElement
	\date		04 08 05
	\author		Abvent R&D copyright (C) 2005
	\author		Guillaume Boulet-Gercourt
	\brief		Describes an animated element for Artlantis Studio
*/
class	IAtlAnimatedElement
{
public:
	/// Put an XML representation of the animated element inside the father node.
	/** \retval the new node of the animated element.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the animated element with the XML.
	/** \retval true initialisation from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// get / set the id of this element. This id is an UUID of an ATL element, like a light, object instance, ...
	virtual tUUID		getId() const = 0;
	virtual void		setId(tUUID inId) = 0;

	/// describe the type of this element.
	enum	eElementType
	{
		kUnknow = 0,
		kCamera,
		kLight,
		kHeliodon,
		kObjectInstance,
		kProperty,
		kMappingNode
		// todo : should we put here types like "Atmosphere", "Background", ... ?
	};
	/// get / set the element type.
	virtual eElementType	getType() const = 0;
	virtual void			setType(eElementType inType) = 0;

	/// get the interpolated values list. for consulting
	virtual const AtlInterpolatedValuesMgr*	getInterpolatedValuesMgr() const = 0;
	/// get the interpolated values list. for editing
	virtual AtlInterpolatedValuesMgr*		getInterpolatedValuesMgr() = 0;
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual ~IAtlAnimatedElement() {}
};

}

#endif
