/*!
	\file	IAtlGround.h
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	23 01 06
	\brief	Header for the IAtlGround interface
*/

#ifndef	IAtlGround_h
#define	IAtlGround_h

#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif

namespace AvAtl {

/// List of environments
typedef TAtlObjectMgr<class IAtlGround>			AtlGroundsMgr;


/*!
	\interface IAtlGround
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	23 01 06
	
	\brief	describes a virtual ground for a view
*/
class	IAtlGround
{
public:
	/// get active flag
	virtual bool					getActiveFlag() const = 0;
	/// set active flag
	virtual void					setActiveFlag(bool inFlag) = 0;

	/// get the uuid of this ground
	virtual tUUID					getGroundId() const = 0;
	/// set the uuid of this ground
	virtual void					setGroupId(tUUID inId) = 0;

	/// get the height of the ground
	virtual double					getHeight() const = 0;
	/// set the height of the ground
	virtual void					setHeight(double inHeight) = 0;

	/// get the attached property of the ground. For consulting.
	virtual const class CAtlProperty*	getProperty() const = 0;
	/// get the attached property of the ground. For editing.
	virtual class CAtlProperty*			getProperty() = 0;

	/// Put an XML representation of the ground inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the ground with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(ConstXMLNodeRef inFatherNode) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtlGround() {}
};

} // namespace AvAtl

#endif
