/**
\file IAtlTCE.h

\verbatim
 Copyright (c) 2000 ABVENT R&D

 Files               :  IAtlTCE.h
 Autor               :  Richard Young
 Creation date       :  12/01/2012
 Description         :  Private Interface for Property TCE
 Modifications       :
\endverbatim
*/


#ifndef IAtlTCE_h
#define IAtlTCE_h


#include "CATL/AvAtlTypes.h"


// We use this namespace for our library.
namespace  AvAtl {


class IRootNode;


// API for property
class IAtlTCE
{
public:
	// Get the shader url
	virtual tURL				getShaderURL() const = 0;
	// Change the shader url
	virtual void				setShaderURL(tURL inURL) = 0;

	// Get the shader id
	virtual tUUID				getShaderId() const = 0;
	// Change the shader id
	virtual void				setShaderId(tUUID inShaderId) = 0;

	// Get the shader name (for consultation only)
	virtual const IAtlString&	getShaderName() const = 0;
	// Get the shader name (for modification)
	virtual IAtlString&			getShaderName() = 0;

	// Return the root node (for consultation only)
	virtual const IRootNode*	getRoot() const = 0;
	// Return the root node.
	virtual IRootNode*			getRoot() = 0;

#ifdef ITCENode_h
	// Create tce node.
	virtual ITCENode::AutoPtr	createNode(ITCENode::ENodeType inNodeType) = 0;
#endif

protected:
	// You must not create or delete objects of this class.
	// This is the responsability of the CAtlMgr class.
	~IAtlTCE() {}
};


} // namespace  AvAtl

#endif
