/**
 \file ILeafNode.h
 
 Interface class for leaf TCE node.
 
 \verbatim
 
 File			:	ILeafNode.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface ILeafNode is the class for leaf node in tce tree.
 
 Modifications	:
 
 \endverbatim
 */


#ifndef ILeafNode_h
#define ILeafNode_h


#ifndef CAtlColor_h
	#include "CATL/CAtlColor.h"
#endif


namespace AvAtl{


// Forward declarations.
class ITCENode;


/// The interface ILeafNode is the class for leaf node in tce tree
/** \interface ILeafNode
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
class ILeafNode
{
public:
	// For ATL library internal usage only.
#ifdef ITCENode_h
	enum { mType = ITCENode::eLeafNode };
#endif

	/// Return the node of this leaf.
	virtual const ITCENode*		asNode() const = 0;
	virtual ITCENode*			asNode() = 0;

	/// Leaf getters/setters.
	virtual const CAtlColor&	getDiffuseColor() const = 0;
	virtual void				setDiffuseColor(const CAtlColor& inColor) = 0;

	virtual const CAtlColor&	getTransparentColor() const = 0;
	virtual void				setTransparentColor(const CAtlColor& inColor) = 0;

	virtual const CAtlColor&	getSpecularColor() const = 0;
	virtual void				setSpecularColor(const CAtlColor& inColor) = 0;

	virtual const CAtlColor&	getReflectionColor() const = 0;
	virtual void				setReflectionColor(const CAtlColor& inColor) = 0;

	virtual double				getReflectionLimit() const = 0;
	virtual void				setReflectionLimit(double inReflectionLimit) = 0;

	virtual const CAtlColor&	getNeonColor() const = 0;
	virtual void				setNeonColor(const CAtlColor& inColor) = 0;

	virtual double				getNeon() const = 0;
	virtual void				setNeon(double inNeon) = 0;

	virtual double				getRefraction() const = 0;
	virtual void				setRefraction(double inRefraction) = 0;

	virtual double				getGlossy() const = 0;
	virtual void				setGlossy(double inGlossy) = 0;

	virtual const CAtlColor&	getEmittingColor() const = 0;
	virtual void				setEmittingColor(const CAtlColor& inColor) = 0;

	virtual double				getEmittingPower() const = 0;
	virtual void				setEmittingPower(double inPower) = 0;

protected:
	/// Don't delete, use node refcount
								~ILeafNode() {};
};


} // namespace  AvAtl

#endif
