/**
 \file ITable.h
 
 Interface class for table (Used for turbulence noise and chess smothing).
 
 \verbatim
 
 File			:	ITable.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface ITable is the class for table (Used for turbulence noise and chess smothing).
 
 Modifications	:
 
 \endverbatim
 */


#ifndef ITable_h
#define ITable_h


#ifndef TAtlAutoPtr_h
	#include "TAtlAutoPtr.h"
#endif


namespace AvAtl{


/// The interface ITable is the class for table (Used for turbulence noise and chess smothing)
/** \interface ITable
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
// .
class ITable
{
public:
	typedef TAtlAutoPtr<ITable>	AutoPtr;

	/// Increment the number of referents
	virtual void			AddRef() = 0;

	/// Decrement the number of referents
	virtual void			Release() = 0;

	///return the length of the table
	virtual int 			getLength() const = 0;

	/**
	 set the length of the table
	 note that if the length is smaller that the previous lenght some data will be lost */
	virtual void		 	setLength(int length) = 0;

	///get the data at the specified index
	virtual float			getData(int index) const = 0;

	///set the data at the specified index
	virtual void			setData(int index, float data) = 0;

protected:
	// Don't delete, use refcount.
							~ITable() {};
};


} // namespace  AvAtl

#endif
