/**
 \file ITurbulenceNode.h
 
 Interface class for turbulence TCE node.
 
 \verbatim
 
 File			:	ITurbulenceNode.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface ITurbulenceNode is the class for turbulence node in tce tree.
 
 Modifications	:
 
 \endverbatim
 */


#ifndef ITurbulenceNode_h
#define ITurbulenceNode_h


#ifndef CAtlVector_h
	#include "CATL/CAtlVector.h"
#endif
#ifndef ITable_h
	#include "CATL/ITable.h"
#endif


namespace AvAtl{


// Forward declarations.
class ITCENode;
class ITable;


/// The interface ITurbulenceNode is the class for turbulence node in tce tree
/** \interface ITurbulenceNode
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
class ITurbulenceNode
{
public:
	// For ATL library internal usage only.
#ifdef ITCENode_h
	enum { mType = ITCENode::eTurbulenceNode };
#endif

	// Return the node of this turbulence.
	virtual const ITCENode*		asNode() const = 0;
	virtual ITCENode*			asNode() = 0;

	// Turbulence getters/setters.
	virtual const CAtlVector&	getOrigin() const = 0;
	virtual void				setOrigin(const CAtlVector& inOrigin) = 0;

	virtual const CAtlVector&	getAmplitude() const = 0;
	virtual void				setAmplitude(const CAtlVector& inAmplitude) = 0;

	virtual const CAtlVector&	getDirection() const = 0;
	virtual void				setDirection(const CAtlVector& inDirection) = 0;

	virtual double				getSize() const = 0;
	virtual void				setSize(double inSize) = 0;

	virtual const ITable*		getTable() const = 0;
	virtual ITable*				getTable() = 0;

protected:
	// Don't delete, use node refcount
								~ITurbulenceNode() {};
};
	
	
} // namespace  AvAtl

#endif
